@@ -24,7 +24,7 @@ def show_version():
     print("DWF library version ...... : {}".format(dwf.getVersion()))
 
 
-def list_devices(use_obsolete_api: bool, list_configurations: bool):
+def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltips_flag: bool):
     """List devices supported by the DWF library."""
 
     # pylint: disable = too-many-locals, too-many-branches, too-many-statements, too-many-nested-blocks
@@ -90,14 +90,18 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool):
             string_lookup_table: Dict[str, str] = {}
 
             for configuration_parameter in DwfEnumConfigInfo:
+
                 for configuration_index in range(num_config):
                     config_value = str(dwf.deviceEnum.configInfo(configuration_index, configuration_parameter))
 
-                    if config_value in string_lookup_table:
+                    if not full_tooltips_flag and configuration_parameter == DwfEnumConfigInfo.TooltipText:
+                        shorthand = "({})".format(len(config_value))
+                        configuration_data[(configuration_index, configuration_parameter)] = shorthand
+                    elif config_value in string_lookup_table:
                         configuration_data[(configuration_index, configuration_parameter)] = \
                             string_lookup_table[config_value]
                     elif not re_short_strings.match(config_value):
-                        shorthand = "[{}]".format(len(string_lookup_table) + 1)
+                        shorthand = "[{}]".format(len(string_lookup_table))
                         string_lookup_table[config_value] = shorthand
                         configuration_data[(configuration_index, configuration_parameter)] = shorthand
                     else:
@@ -109,7 +113,13 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool):
                 "  ".join("--------" for configuration_index in range(num_config))))
 
             for configuration_parameter in DwfEnumConfigInfo:
-                print("  {:22}  {}".format(configuration_parameter.name, "  ".join("{:>8s}".format(
+
+                if not full_tooltips_flag and configuration_parameter == DwfEnumConfigInfo.TooltipText:
+                    parameter_name = "{} (length)".format(configuration_parameter.name)
+                else:
+                    parameter_name = configuration_parameter.name
+
+                print("  {:22}  {}".format(parameter_name, "  ".join("{:>8s}".format(
                     configuration_data[(configuration_index, configuration_parameter)])
                         for configuration_index in range(num_config))))
             print()
@@ -193,8 +203,13 @@ def main():
         action='store_true',
         help="for each device, printing its configurations", dest='list_configurations')
 
+    subparser_list.add_argument(
+        '-f', '--full-tooltips',
+        action='store_true',
+        help="show full TooltipText strings instead of length", dest='full_tooltips')
+
     subparser_list.set_defaults(
-        execute=lambda args: list_devices(args.use_obsolete_api, args.list_configurations))
+        execute=lambda args: list_devices(args.use_obsolete_api, args.list_configurations, args.full_tooltips))
 
     # Declare the sub-parser for the "extract-examples" command.
 
