@@ -15,8 +15,7 @@ from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
 class AnalogIn(DwfDevice_SubAPI):
-    """The |AnalogIn| class provides access to the AnalogIn (oscilloscope) instrument of a
-    |DwfDevice:link|.
+    """The |AnalogIn| class provides access to the AnalogIn (oscilloscope) instrument of a |DwfDevice:link|.
 
     Attention:
         Users of |pydwf| should not create instances of this class directly.
@@ -27,6 +26,12 @@ class AnalogIn(DwfDevice_SubAPI):
 
     # pylint: disable=too-many-public-methods
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               INSTRUMENT CONTROL                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def reset(self) -> None:
         """Reset all AnalogIn instrument parameters to default values.
 
@@ -55,18 +60,6 @@ class AnalogIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerForce(self) -> None:
-        """Force assertion of the instrument trigger.
-
-        (To do: Figure out if this triggers the AnalogIn instrument or the AnalogIn trigger detector).
-
-        Raises:
-            DwfLibraryError: There was an error while executing the *triggerForce* operation.
-        """
-        result = self.lib.FDwfAnalogInTriggerForce(self.hdwf)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
     def status(self, read_data: bool) -> DwfState:
         """Check the status of the instrument.
 
@@ -111,21 +104,11 @@ class AnalogIn(DwfDevice_SubAPI):
         status_ = DwfState(c_status.value)
         return status_
 
-    def statusSamplesLeft(self) -> int:
-        """Retrieve the number of samples left in the acquisition, in samples.
-
-        Returns:
-            int: In case a finite-duration acquisition is active, the number of samples left in the acquisition.
-
-        Raises:
-            DwfLibraryError: There was an error while retrieving the number of samples left.
-        """
-        c_samples_left = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInStatusSamplesLeft(self.hdwf, c_samples_left)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        samples_left = c_samples_left.value
-        return samples_left
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               STATUS VARIABLES                                                   #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def statusTime(self) -> Tuple[int, int, int]:
         """Retrieve the timestamp of the current status information.
@@ -152,6 +135,60 @@ class AnalogIn(DwfDevice_SubAPI):
         ticks_per_second = c_ticks_per_second.value
         return (sec_utc, tick, ticks_per_second)
 
+    def statusSample(self, channel_index: int) -> float:
+        """Get the last ADC conversion sample from the specified AnalogIn instrument channel, in Volts.
+
+        Note:
+            This value is updated even if the `status` method is called with argument False.
+
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+
+        Returns:
+            float: The most recent ADC value of this channel, in Volts.
+
+        Raises:
+            DwfLibraryError: There was an error while retrieving the sample value.
+        """
+        c_sample = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInStatusSample(self.hdwf, channel_index, c_sample)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        sample = c_sample.value
+        return sample
+
+    def statusAutoTriggered(self) -> bool:
+        """Verify if the current acquisition is auto-triggered.
+
+        Returns:
+            bool: True if the current acquisition is auto-triggered, False otherwise.
+
+        Raises:
+            DwfLibraryError: There was an error while retrieving the auto-triggered state.
+        """
+        c_auto_triggered = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInStatusAutoTriggered(self.hdwf, c_auto_triggered)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        auto_triggered = bool(c_auto_triggered.value)
+        return auto_triggered
+
+    def statusSamplesLeft(self) -> int:
+        """Retrieve the number of samples left in the acquisition, in samples.
+
+        Returns:
+            int: In case a finite-duration acquisition is active, the number of samples left in the acquisition.
+
+        Raises:
+            DwfLibraryError: There was an error while retrieving the number of samples left.
+        """
+        c_samples_left = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInStatusSamplesLeft(self.hdwf, c_samples_left)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        samples_left = c_samples_left.value
+        return samples_left
+
     def statusSamplesValid(self) -> int:
         """Retrieve the number of valid acquired data samples.
 
@@ -191,44 +228,6 @@ class AnalogIn(DwfDevice_SubAPI):
         index_write = c_index_write.value
         return index_write
 
-    def statusAutoTriggered(self) -> bool:
-        """Verify if the current acquisition is auto-triggered.
-
-        Returns:
-            bool: True if the current acquisition is auto-triggered, False otherwise.
-
-        Raises:
-            DwfLibraryError: There was an error while retrieving the auto-triggered state.
-        """
-        c_auto_triggered = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInStatusAutoTriggered(self.hdwf, c_auto_triggered)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        auto_triggered = bool(c_auto_triggered.value)
-        return auto_triggered
-
-    def statusSample(self, channel_index: int) -> float:
-        """Get the last ADC conversion sample from the specified AnalogIn instrument channel, in Volts.
-
-        Note:
-            This value is updated even if the `status` method is called with argument False.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-
-        Returns:
-            float: The most recent ADC value of this channel, in Volts.
-
-        Raises:
-            DwfLibraryError: There was an error while retrieving the sample value.
-        """
-        c_sample = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInStatusSample(self.hdwf, channel_index, c_sample)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        sample = c_sample.value
-        return sample
-
     def statusRecord(self) -> Tuple[int, int, int]:
         """Retrieve information about the recording process.
 
@@ -240,12 +239,12 @@ class AnalogIn(DwfDevice_SubAPI):
         previous read.
 
         In this case, try optimizing the loop process for faster execution or reduce the acquisition frequency or
-        record length to be less than or equal to the device buffer size (i.e.,
-        record_length is less than or equal to buffer_size / sample_frequency).
+        record length to be less than or equal to the device buffer size (i.e., record_length is less than or
+        equal to buffer_size / sample_frequency).
 
         Returns:
             Tuple[int, int, int]: A three-element tuple containing three counts for
-                available*, *lost*, and *corrupt* data samples, in that order.
+                *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
             DwfLibraryError: There was an error while retrieving the record status.
@@ -265,6 +264,12 @@ class AnalogIn(DwfDevice_SubAPI):
         data_corrupt = c_data_corrupt.value
         return (data_available, data_lost, data_corrupt)
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               STATUS DATA RETRIEVAL                                              #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def statusData(self, channel_index: int, count: int) -> np.ndarray:
         """Retrieve the acquired data samples from the specified AnalogIn instrument channel.
 
@@ -423,7 +428,35 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
         return (noise_min, noise_max)
 
-    # Acquisition configuration:
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               ACQUISITION CONFIGURATION                                          #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def bitsInfo(self) -> int:
+        """Get the fixed the number of bits used by the AnalogIn ADC.
+
+        This number of bits can only be queried; it cannot be changed.
+
+        Note:
+            The Analog Discovery 2 uses an `Analog Devices AD9648
+            <https://www.analog.com/media/en/technical-documentation/data-sheets/AD9648.pdf>`_ two-channel ADC.
+            It converts 14-bit samples at a rate of up to 125 MHz. So for the Analog Discovery 2, this method
+            always returns 14.
+
+        Returns:
+            int: The number of bits per sample for each of the AnalogIn channels.
+
+        Raises:
+            DwfLibraryError: There was an error while getting the number of bits.
+        """
+        c_num_bits = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInBitsInfo(self.hdwf, c_num_bits)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        num_bits = c_num_bits.value
+        return num_bits
 
     def recordLengthSet(self, record_duration: float) -> None:
         """Set the record length, in seconds.
@@ -514,30 +547,6 @@ class AnalogIn(DwfDevice_SubAPI):
         sample_frequency = c_sample_frequency.value
         return sample_frequency
 
-    def bitsInfo(self) -> int:
-        """Get the fixed the number of bits used by the AnalogIn ADC.
-
-        This number of bits can only be queried; it cannot be changed.
-
-        Note:
-            The Analog Discovery 2 uses an `Analog Devices AD9648
-            <https://www.analog.com/media/en/technical-documentation/data-sheets/AD9648.pdf>`_ two-channel ADC.
-            It converts 14-bit samples at a rate of up to 125 MHz. So for the Analog Discovery 2, this method
-            always returns 14.
-
-        Returns:
-            int: The number of bits per sample for each of the AnalogIn channels.
-
-        Raises:
-            DwfLibraryError: There was an error while getting the number of bits.
-        """
-        c_num_bits = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInBitsInfo(self.hdwf, c_num_bits)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        num_bits = c_num_bits.value
-        return num_bits
-
     def bufferSizeInfo(self) -> Tuple[int, int]:
         """Returns the minimum and maximum allowable buffer size for the instrument, in samples.
 
@@ -708,7 +717,11 @@ class AnalogIn(DwfDevice_SubAPI):
         acquisition_mode = DwfAcquisitionMode(c_acquisition_mode.value)
         return acquisition_mode
 
-    # Channel configuration:
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                    CHANNEL COUNT                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def channelCount(self) -> int:
         """Read the number of analog input channels.
@@ -726,6 +739,12 @@ class AnalogIn(DwfDevice_SubAPI):
         channel_count = c_channel_count.value
         return channel_count
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                 CHANNEL CONFIGURATION                                            #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def channelEnableSet(self, channel_index: int, enable: bool) -> None:
         """Enable or disable the specified analog input channel.
 
@@ -827,43 +846,23 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the analog input range setting info.
         """
-        c_voltsMin = typespec_ctypes.c_double()
-        c_voltsMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInChannelRangeInfo(self.hdwf, c_voltsMin, c_voltsMax, c_nSteps)
+        c_channel_range_min = typespec_ctypes.c_double()
+        c_channel_range_max = typespec_ctypes.c_double()
+        c_channel_range_num_steps = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInChannelRangeInfo(
+            self.hdwf,
+            c_channel_range_min,
+            c_channel_range_max,
+            c_channel_range_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        voltsMin = c_voltsMin.value
-        voltsMax = c_voltsMax.value
-        # nSteps is retrieved as a double, but its value can always be expressed as an integer in Python.
-        nSteps = round(c_nSteps.value)
-        return (voltsMin, voltsMax, nSteps)
 
-    def channelRangeSteps(self) -> List[float]:
-        """Report the possible voltage ranges of the analog input channels, in Volts, as a list.
-
-        The values returned represent ideal values.
-        The actual calibrated ranges are channel-dependent.
-
-        See Also:
-            The :py:meth:`channelRangeInfo` method returns essentially the same information
-            in a different representation.
-
-        Returns:
-            List[float]: A list of ranges, in Volts, representing the discrete
-                channel range settings of the |AnalogIn| instrument.
-
-        Raises:
-            DwfLibraryError: there was an error while getting the list of analog input range settings.
-        """
-        c_rgVoltsStep = typespec_ctypes.c_double_array_32()
-        c_nSteps = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInChannelRangeSteps(self.hdwf, c_rgVoltsStep, c_nSteps)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        nSteps = c_nSteps.value
-        rgVoltsStep = [c_rgVoltsStep[index] for index in range(nSteps)]
-        return rgVoltsStep
+        channel_range_min = c_channel_range_min.value
+        channel_range_max = c_channel_range_max.value
+        if not c_channel_range_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_channel_range_num_steps value.")
+        channel_range_num_steps = int(c_channel_range_num_steps.value)
+        return (channel_range_min, channel_range_max, channel_range_num_steps)
 
     def channelRangeSet(self, channel_index: int, channel_range: float) -> None:
         """Set the range setting of the specified channel, in Volts.
@@ -906,6 +905,32 @@ class AnalogIn(DwfDevice_SubAPI):
         channel_range = c_channel_range.value
         return channel_range
 
+    def channelRangeSteps(self) -> List[float]:
+        """Report the possible voltage ranges of the analog input channels, in Volts, as a list.
+
+        The values returned represent ideal values.
+        The actual calibrated ranges are channel-dependent.
+
+        See Also:
+            The :py:meth:`channelRangeInfo` method returns essentially the same information
+            in a different representation.
+
+        Returns:
+            List[float]: A list of ranges, in Volts, representing the discrete
+                channel range settings of the |AnalogIn| instrument.
+
+        Raises:
+            DwfLibraryError: there was an error while getting the list of analog input range settings.
+        """
+        c_channel_range_array = typespec_ctypes.c_double_array_32()
+        c_channel_range_array_size = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInChannelRangeSteps(self.hdwf, c_channel_range_array, c_channel_range_array_size)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        channel_range_array_size = c_channel_range_array_size.value
+        channel_range_array = [c_channel_range_array[index] for index in range(channel_range_array_size)]
+        return channel_range_array
+
     def channelOffsetInfo(self) -> Tuple[float, float, int]:
         """Get the possible channel offset settings, in Volts.
 
@@ -916,16 +941,18 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the channel offset info.
         """
-        c_voltsMin = typespec_ctypes.c_double()
-        c_voltsMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInChannelOffsetInfo(self.hdwf, c_voltsMin, c_voltsMax, c_nSteps)
+        c_offset_min = typespec_ctypes.c_double()
+        c_offset_max = typespec_ctypes.c_double()
+        c_offset_num_steps = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInChannelOffsetInfo(self.hdwf, c_offset_min, c_offset_max, c_offset_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        voltsMin = c_voltsMin.value
-        voltsMax = c_voltsMax.value
-        nSteps = round(c_nSteps.value)
-        return (voltsMin, voltsMax, nSteps)
+        offset_min = c_offset_min.value
+        offset_max = c_offset_max.value
+        if not c_offset_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_offset_num_steps value.")
+        offset_num_steps = int(c_offset_num_steps.value)
+        return (offset_min, offset_max, offset_num_steps)
 
     def channelOffsetSet(self, channel_index: int, channel_offset: float) -> None:
         """Set the channel offset, in Volts.
@@ -968,7 +995,7 @@ class AnalogIn(DwfDevice_SubAPI):
         channel_offset = c_channel_offset.value
         return channel_offset
 
-    def channelAttenuationSet(self, channel_index: int, attenuation: float) -> None:
+    def channelAttenuationSet(self, channel_index: int, channel_attenuation: float) -> None:
         """Set the channel attenuation setting.
 
         The channel attenuation is a dimensionless factor.
@@ -992,7 +1019,7 @@ class AnalogIn(DwfDevice_SubAPI):
         result = self.lib.FDwfAnalogInChannelAttenuationSet(
             self.hdwf,
             channel_index,
-            attenuation)
+            channel_attenuation)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1015,17 +1042,17 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the current channel attenuation.
         """
-        c_attenuation = typespec_ctypes.c_double()
+        c_channel_attenuation = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogInChannelAttenuationGet(
             self.hdwf,
             channel_index,
-            c_attenuation)
+            c_channel_attenuation)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        attenuation = c_attenuation.value
-        return attenuation
+        channel_attenuation = c_channel_attenuation.value
+        return channel_attenuation
 
-    def channelBandwidthSet(self, channel_index: int, bandwidth: float) -> None:
+    def channelBandwidthSet(self, channel_index: int, channel_bandwidth: float) -> None:
         """Set the channel bandwidth setting.
 
         Parameters:
@@ -1039,7 +1066,7 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while setting the channel bandwidth.
         """
-        result = self.lib.FDwfAnalogInChannelBandwidthSet(self.hdwf, channel_index, bandwidth)
+        result = self.lib.FDwfAnalogInChannelBandwidthSet(self.hdwf, channel_index, channel_bandwidth)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1059,14 +1086,14 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the current channel bandwidth.
         """
-        c_bandwidth = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInChannelBandwidthGet(self.hdwf, channel_index, c_bandwidth)
+        c_channel_bandwidth = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInChannelBandwidthGet(self.hdwf, channel_index, c_channel_bandwidth)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        bandwidth = c_bandwidth.value
-        return bandwidth
+        channel_bandwidth = c_channel_bandwidth.value
+        return channel_bandwidth
 
-    def channelImpedanceSet(self, channel_index: int, impedance: float) -> None:
+    def channelImpedanceSet(self, channel_index: int, channel_impedance: float) -> None:
         """Set the channel impedance setting, in Ohms.
 
         Parameters:
@@ -1080,7 +1107,7 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while setting the current channel impedance.
         """
-        result = self.lib.FDwfAnalogInChannelImpedanceSet(self.hdwf, channel_index, impedance)
+        result = self.lib.FDwfAnalogInChannelImpedanceSet(self.hdwf, channel_index, channel_impedance)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1100,14 +1127,18 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the current channel impedance.
         """
-        c_impedance = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInChannelImpedanceGet(self.hdwf, channel_index, c_impedance)
+        c_channel_impedance = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInChannelImpedanceGet(self.hdwf, channel_index, c_channel_impedance)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        impedance = c_impedance.value
-        return impedance
+        channel_impedance = c_channel_impedance.value
+        return channel_impedance
 
-    # Trigger configuration:
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                         INSTRUMENT TRIGGER CONFIGURATION                                         #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get analog-in trigger source info.
@@ -1180,7 +1211,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
         if not c_trigger_position_num_steps.value.is_integer():
-            raise PyDwfError("Bad number of steps received.")
+            raise PyDwfError("Bad c_trigger_position_num_steps value.")
 
         trigger_position_min = c_trigger_position_min.value
         trigger_position_max = c_trigger_position_max.value
@@ -1241,6 +1272,32 @@ class AnalogIn(DwfDevice_SubAPI):
         trigger_position = c_trigger_position.value
         return trigger_position
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               FORCE INSTRUMENT TRIGGER                                           #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def triggerForce(self) -> None:
+        """Force assertion of the instrument trigger.
+
+        Note:
+            This method forces the |AnalogIn| device to act as if it was triggered, independent of the currently
+            active trigger source. It does not generate an artificial trigger event on the |AnalogIn| trigger detector.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfAnalogInTriggerForce(self.hdwf)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               TRIGGER DETECTOR CONFIGURATION                                     #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
         """Get trigger auto-timeout info.
 
@@ -1250,27 +1307,27 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger auto-timeout info.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_auto_timeout_min = typespec_ctypes.c_double()
+        c_auto_timeout_max = typespec_ctypes.c_double()
+        c_auto_timeout_num_steps = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogInTriggerAutoTimeoutInfo(
             self.hdwf,
-            c_secMin,
-            c_secMax,
-            c_nSteps)
+            c_auto_timeout_min,
+            c_auto_timeout_max,
+            c_auto_timeout_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
-            raise PyDwfError("Bad auto-timeout info number of steps.")
+        if not c_auto_timeout_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_auto_timeout_num_steps value.")
 
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        nSteps = int(c_nSteps.value)
+        auto_timeout_min = c_auto_timeout_min.value
+        auto_timeout_max = c_auto_timeout_max.value
+        auto_timeout_num_steps = int(c_auto_timeout_num_steps.value)
 
-        return (secMin, secMax, nSteps)
+        return (auto_timeout_min, auto_timeout_max, auto_timeout_num_steps)
 
-    def triggerAutoTimeoutSet(self, timeout_setting: float) -> None:
+    def triggerAutoTimeoutSet(self, trigger_autotimeout: float) -> None:
         """Set the trigger auto-timeout value.
 
         Parameters:
@@ -1279,7 +1336,7 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while setting the trigger auto-timeout value.
         """
-        result = self.lib.FDwfAnalogInTriggerAutoTimeoutSet(self.hdwf, timeout_setting)
+        result = self.lib.FDwfAnalogInTriggerAutoTimeoutSet(self.hdwf, trigger_autotimeout)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1292,12 +1349,12 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger auto-timeout value.
         """
-        c_secTimeout = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerAutoTimeoutGet(self.hdwf, c_secTimeout)
+        c_trigger_autotimeout = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerAutoTimeoutGet(self.hdwf, c_trigger_autotimeout)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secTimeout = c_secTimeout.value
-        return secTimeout
+        trigger_autotimeout = c_trigger_autotimeout.value
+        return trigger_autotimeout
 
     def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
         """Get trigger holdoff info.
@@ -1311,24 +1368,28 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger holdoff info.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_trigger_holdoff_min = typespec_ctypes.c_double()
+        c_trigger_holdoff_max = typespec_ctypes.c_double()
+        c_trigger_holdoff_num_steps = typespec_ctypes.c_double()
 
-        result = self.lib.FDwfAnalogInTriggerHoldOffInfo(self.hdwf, c_secMin, c_secMax, c_nSteps)
+        result = self.lib.FDwfAnalogInTriggerHoldOffInfo(
+            self.hdwf,
+            c_trigger_holdoff_min,
+            c_trigger_holdoff_max,
+            c_trigger_holdoff_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
-            raise PyDwfError("Bad trigger hold-time info number of steps.")
+        if not c_trigger_holdoff_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_holdoff_num_steps value.")
 
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        nSteps = int(c_nSteps.value)
+        trigger_holdoff_min = c_trigger_holdoff_min.value
+        trigger_holdoff_max = c_trigger_holdoff_max.value
+        trigger_holdoff_num_steps = int(c_trigger_holdoff_num_steps.value)
 
-        return (secMin, secMax, nSteps)
+        return (trigger_holdoff_min, trigger_holdoff_max, trigger_holdoff_num_steps)
 
-    def triggerHoldOffSet(self, holdoff_setting: float) -> None:
+    def triggerHoldOffSet(self, trigger_holdoff: float) -> None:
         """Set trigger holdoff value.
 
         Parameters:
@@ -1337,7 +1398,7 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while setting the trigger holdoff value.
         """
-        result = self.lib.FDwfAnalogInTriggerHoldOffSet(self.hdwf, holdoff_setting)
+        result = self.lib.FDwfAnalogInTriggerHoldOffSet(self.hdwf, trigger_holdoff)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1350,12 +1411,12 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger holdoff value.
         """
-        c_secHoldOff = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerHoldOffGet(self.hdwf, c_secHoldOff)
+        c_trigger_holdoff = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerHoldOffGet(self.hdwf, c_trigger_holdoff)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secHoldOff = c_secHoldOff.value
-        return secHoldOff
+        trigger_holdoff = c_trigger_holdoff.value
+        return trigger_holdoff
 
     def triggerTypeInfo(self) -> List[DwfTriggerType]:
         """Get the trigger type info.
@@ -1518,22 +1579,26 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger level info.
         """
-        c_voltsMin = typespec_ctypes.c_double()
-        c_voltsMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_trigger_level_min = typespec_ctypes.c_double()
+        c_trigger_level_max = typespec_ctypes.c_double()
+        c_trigger_level_num_steps = typespec_ctypes.c_double()
 
-        result = self.lib.FDwfAnalogInTriggerLevelInfo(self.hdwf, c_voltsMin, c_voltsMax, c_nSteps)
+        result = self.lib.FDwfAnalogInTriggerLevelInfo(
+            self.hdwf,
+            c_trigger_level_min,
+            c_trigger_level_max,
+            c_trigger_level_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
-            raise PyDwfError("Bad trigger level info number of steps.")
+        if not c_trigger_level_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_level_num_steps value")
 
-        voltsMin = c_voltsMin.value
-        voltsMax = c_voltsMax.value
-        nSteps = int(c_nSteps.value)
+        trigger_level_min = c_trigger_level_min.value
+        trigger_level_max = c_trigger_level_max.value
+        trigger_level_num_steps = int(c_trigger_level_num_steps.value)
 
-        return (voltsMin, voltsMax, nSteps)
+        return (trigger_level_min, trigger_level_max, trigger_level_num_steps)
 
     def triggerLevelSet(self, trigger_level: float) -> None:
         """Set |AnalogIn| trigger detector level, in Volts.
@@ -1586,7 +1651,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
         if not c_trigger_hysteresis_num_steps.value.is_integer():
-            raise PyDwfError("Bad trigger hysteresis info number of steps.")
+            raise PyDwfError("Bad c_trigger_hysteresis_num_steps value.")
 
         trigger_hysteresis_min = c_trigger_hysteresis_min.value
         trigger_hysteresis_max = c_trigger_hysteresis_max.value
@@ -1682,13 +1747,16 @@ class AnalogIn(DwfDevice_SubAPI):
         c_trigger_length_max = typespec_ctypes.c_double()
         c_trigger_length_num_steps = typespec_ctypes.c_double()
 
-        result = self.lib.FDwfAnalogInTriggerLengthInfo(self.hdwf, c_trigger_length_min, c_trigger_length_max,
-                                                        c_trigger_length_num_steps)
+        result = self.lib.FDwfAnalogInTriggerLengthInfo(
+            self.hdwf,
+            c_trigger_length_min,
+            c_trigger_length_max,
+            c_trigger_length_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
         if not c_trigger_length_num_steps.value.is_integer():
-            raise PyDwfError("Bad trigger length info number of steps.")
+            raise PyDwfError("Bad c_trigger_length_num_steps value.")
 
         trigger_length_min = c_trigger_length_min.value
         trigger_length_max = c_trigger_length_max.value
@@ -1775,6 +1843,12 @@ class AnalogIn(DwfDevice_SubAPI):
         trigger_length_condition = DwfTriggerLengthCondition(c_trigger_length_condition.value)
         return trigger_length_condition
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               SAMPLING CLOCK CONFIGURATION                                       #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def samplingSourceSet(self, sampling_source: DwfTriggerSource) -> None:
         """Set |AnalogIn| sampling source.
 
