@@ -88,7 +88,7 @@ class DigitalCan(DwfDevice_SubAPI):
             v_id (int): (to be documented)
             extended (bool): (to be documented)
             remote (bool): (to be documented)
-            data (bytes): Data to be transmitted. Should be at most 8 bytes.
+            data (bytes): The data to be transmitted. Should be at most 8 bytes.
 
         Raises:
             PyDwfError: A request to transmit more than 8 bytes was made.
