@@ -184,7 +184,7 @@ class DwfDevice:
         """Return the auto-configuration setting of the device.
 
         Returns:
-            The auto-configure setting
+            The current auto-configure setting.
 
             Possible values:
 
