@@ -30,8 +30,25 @@ class DwfLibrary:
     def __init__(self, check_library_version: bool = True) -> None:
         """Initialize a |DwfLibrary| instance.
 
-        This method instantiates a |ctypes:link| shared library, type-annotates its functions, and initializes the
-        |deviceEnum:link| and |deviceControl:link| attributes that provide access to |device enumeration:link| and
+        A single |DwfLibrary| instance should be created by a user of |pydwf| to serve as an entry point to all
+        |pydwf| functionality.
+
+        When initializing a |DwfLibrary|, the shared library |libdwf| on which |pydwf| is built is loaded into memory.
+
+        By default, a version check is executed to make sure that the shared library version corresponds exactly to
+        the version that was used while developing and testing the current |pydwf| version (|libdwf-version|), and
+        an exception is raised if a mismatch is detected.
+
+        It is possible to disable this version check by passing False to the *check_library_version* parameter.
+        This is not recommended: some functions may not be available, and some type information may not be correct,
+        which means you may experience strange and hard to debug issues.
+
+        After passing (or skipping) the version check, the functions provided by the shared library are type-annotated.
+        This means that calls into the shared library with incompatible parameter types will raise an exception.
+        This mechanism helps to catch many bugs while using |pydwf|.
+
+        As a last initialization step, the :py:attr:`deviceEnum` and :py:attr:`deviceControl` attributes are
+        initialized. They can be used by a user program to access the |device enumeration:link| and
         |device control:link| functionality.
 
         Parameters:
@@ -40,7 +57,8 @@ class DwfLibrary:
                 a mismatch, an exception will be raised.
 
         Raises:
-            PyDwfError: The version check failed, or a version mismatch was detected.
+            PyDwfError: The version check could not be performed do to an unexpected low-level error while querying the
+                shared library version; or a version mismatch was detected.
         """
 
         if sys.platform.startswith("win"):
